/**
 * apeman react package for demo components
 * @class ApDemo
 */

'use strict'

import React, {PropTypes as types} from 'react'
import fs from 'fs'
import {highlightJsx} from 'ape-highlighting'
import stylesheets from 'apeman-asset-stylesheets'
import {ApStyle} from 'apeman-react-style'
import {ApHtml} from 'apeman-react-html'
import {ApHead} from 'apeman-react-head'
import {ApBody} from 'apeman-react-body'
import {ApLinks} from 'apeman-react-links'
import {ApIconStyle, ApFaIconStyle, ApIonIconStyle} from 'apeman-react-icon'
import {ApSpinnerStyle} from 'apeman-react-spinner'

const DEFAULT_FAVICON_URL = 'https://raw.githubusercontent.com/apeman-asset-labo/apeman-asset-images/master/dist/favicon/react-favicon.png'

/** @lends ApDemo */
const ApDemo = React.createClass({

  // --------------------
  // Specs
  // --------------------

  propTypes: {
    /** Package data */
    pkg: types.object.isRequired,
    /** Source file path of demo target */
    src: types.string.isRequired,
    /** Favicon URL */
    favicon: types.string,
    /** Script file path */
    scripts: types.array,
    /** Link URLs */
    links: types.object,
    /** Additional head child node */
    head: types.node,
    /** Additional body child node */
    body: types.node
  },

  mixins: [],

  statics: {
    DEFAULT_FAVICON_URL
  },

  getInitialState () {
    return {}
  },

  getDefaultProps () {
    return {
      favicon: DEFAULT_FAVICON_URL,
      scripts: [],
      links: {},
      head: null,
      body: null
    }
  },

  render () {
    const s = this
    let { state, props } = s
    let { pkg, src, favicon, scripts, links, children } = props

    return (
      <ApHtml className="react-demo">
        <ApHead charset="UTF-8"
                title={ `${pkg.name} Demo` }
                version={ pkg.version }
                js={ scripts }
                icon={ favicon }>
          <ApStyle data={ fs.readFileSync(stylesheets.reactDemo).toString() }/>
          <ApIconStyle />
          <ApFaIconStyle />
          <ApIonIconStyle />
          <ApSpinnerStyle />
          { props.head }
        </ApHead>
        <ApBody>
          <div id="demo-style"></div>
          <header className="react-demo-header">
            <div className="react-demo-container">
              <h1>
                <a href={ pkg.homepage }>{ pkg.name }</a>
              </h1>
            </div>
          </header>
          <main>
            <div>
              <div className="react-demo-playground">
                <div className="react-demo-container">
                  <div id="demo-wrap">
                    { children }
                  </div>
                </div>
              </div>
            </div>
            <div className="react-demo-container">
              <div>
<pre className="react-demo-src" dangerouslySetInnerHTML={
    { __html: highlightJsx.fromFile(src) }
}>
</pre>
              </div>
            </div>

          </main>
          <footer>
            <div className="react-demo-container">
              <ApLinks links={ links }/>
            </div>
          </footer>
          { props.body }
        </ApBody>
      </ApHtml>
    )
  }

  // ------------------
  // Custom
  // ------------------

  // ------------------
  // Private
  // ------------------
})

export default ApDemo
